plugin_spec

Function plugin_spec 

pub fn plugin_spec(plugin_name: &str, marketplace_name: &str) -> String
The <plugin>@<marketplace> spec codex plugin add and codex plugin remove take, and the key Codex records enablement under in its config.toml.