#[non_exhaustive]pub struct HookPluginTemplates {
pub plugin_manifest: &'static str,
pub hooks_manifest: &'static str,
}Expand description
The two manifests a consumer packages into its plugin source directory, as the registry hands them out.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.plugin_manifest: &'static strPLUGIN_MANIFEST_TEMPLATE, destined for .codex-plugin/plugin.json.
hooks_manifest: &'static strHOOKS_MANIFEST_TEMPLATE, destined for hooks/hooks.json.